@@ -1,5 +1,5 @@
 package Template::Liquid;
-{ $Template::Liquid::VERSION = 'v1.0.3' }
+our $VERSION = '1.0.5';
 our (%tags, %filters);
 #
 use Template::Liquid::Document;
@@ -54,6 +54,8 @@ sub render {
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Template::Liquid - A Simple, Stateless Template System
@@ -326,31 +328,15 @@ L<Template::Liquid::Filters::Standard|Template::Liquid::Filters::Standard>.
 Extending the Template::Liquid template engine for your needs is almost too
 simple. Keep reading.
 
-=head2 Custom Filters
-
-Filters are simple subs called when needed. They are not passed any state data
-by design and must return the modified content.
-
-=for todo I need to write Template::Liquid::Filter which will be POD with all sorts of info in it. Yeah.
-
-=head3 C<< Template::Liquid::register_filter( ... ) >>
-
-This registers a package which Template::Liquid will assume contains one or more
-filters.
-
-    # Register a package as a filter
-    Template::Liquid::register_filter( 'Template::Solution::Filter::Amalgamut' );
-
-    # Or simply say...
-    Template::Liquid::register_filter( );
-    # ...and Template::Liquid will assume the filters are in the calling package
-
 =head2 Custom Tags
 
 See the section entitled
 L<Extending Template::Liquid with Custom Tags|Template::Liquid::Tag/"Extending Template::Liquid with Custom Tags">
 in L<Template::Liquid::Tag> for more information.
 
+Also check out the examples of L<Template::LiquidX::Tag::Dump> and
+L<Template::LiquidX::Tag::Include> now on CPAN.
+
 To assist with custom tag creation, Template::Liquid provides several basic tag types
 for subclassing and exposes the following methods:
 
@@ -369,8 +355,24 @@ both a C<parse> and C<render> method.
 Pre-existing tags are replaced when new tags are registered with the same
 name. You may want to do this to override some functionality.
 
-For an example of a custom tag, see L<Solution::Tag::Include> and
-L<Solution::Tag::Dump>.
+=head2 Custom Filters
+
+Filters are simple subs called when needed. They are not passed any state data
+by design and must return the modified content.
+
+=for todo I need to write Template::Liquid::Filter which will be POD with all sorts of info in it. Yeah.
+
+=head3 C<< Template::Liquid::register_filter( ... ) >>
+
+This registers a package which Template::Liquid will assume contains one or more
+filters.
+
+    # Register a package as a filter
+    Template::Liquid::register_filter( 'Template::Solution::Filter::Amalgamut' );
+
+    # Or simply say...
+    Template::Liquid::register_filter( );
+    # ...and Template::Liquid will assume the filters are in the calling package
 
 =head1 Why should I use Template::Liquid?
 
@@ -407,15 +409,17 @@ yourself. Everyone knows computers cannot be trusted.
 
 =head1 Template::LiquidX or Solution?
 
-I'd really rather use Solution::{Package} for extentions but who cares?
+I'd really rather use Solution::{Package} for extentions but Template::LiquidX
+really is a better choice.
 
 As I understand it, the original project's name, Liquid, is a reference to the
-classical states of matter (the engine itself being stateless). I settled on
-L<solution|http://en.wikipedia.org/wiki/Solution> because it's liquid but...
-with... bits of other stuff floating in it. (Pretend you majored in chemistry
+classical states of matter (the engine itself being stateless). I wanted to
+use L<solution|http://en.wikipedia.org/wiki/Solution> because it's liquid but
+with bits of other stuff floating in it. (Pretend you majored in chemistry
 instead of mathematics or computer science.) Liquid tempates will I<always>
-work with Template::Liquid but (due to Solutions's expanded syntax) Solution
-templates I<may not> be compatible with Liquid or Template::Liquid.
+work with Template::Liquid but (due to Template::LiquidX's expanded syntax)
+Template::LiquidX templates I<may not> be compatible with Liquid or
+Template::Liquid.
 
 =head1 Author
 
@@ -431,7 +435,7 @@ L<Tobias Lütke|http://blog.leetsoft.com/>.
 
 =head1 License and Legal
 
-Copyright (C) 2009-2013 by Sanko Robinson <sanko@cpan.org>
+Copyright (C) 2009-2016 by Sanko Robinson <sanko@cpan.org>
 
 This program is free software; you can redistribute it and/or modify it under
 the terms of
